"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BackupSslCert = void 0;
const package_json_1 = __importDefault(require("../package.json"));
const shelljs_1 = __importDefault(require("shelljs"));
const chalk_1 = __importDefault(require("chalk"));
const aws_sdk_1 = __importDefault(require("aws-sdk"));
const fs_1 = __importDefault(require("fs"));
const acm_utils_1 = require("./utils/acm-utils");
const asg_utils_1 = require("./utils/asg-utils");
class BackupSslCert {
    constructor(options) {
        this.options = options;
        this.acmClient = new aws_sdk_1.default.ACM({
            region: this.options.region,
            apiVersion: '2015-12-08'
        });
        this.autoScalingClient = new aws_sdk_1.default.AutoScaling({
            region: this.options.region
        });
        this.instanceId = shelljs_1.default.exec(`ec2metadata --instance-id`).toString();
        this.run();
    }
    run() {
        try {
            console.log(chalk_1.default.bgGreenBright(`Running SSL certificate backup ${package_json_1.default.version}`));
            this.backupCert().finally(() => __awaiter(this, void 0, void 0, function* () {
                try {
                    yield asg_utils_1.continueLifecycle(this.autoScalingClient, this.options.autoScalingGroupName, this.options.lifecycleHookName, this.options.lifecycleActionToken, this.instanceId);
                }
                catch (e) {
                    console.log(chalk_1.default.bgRedBright(`Failed to continue ASG lifecycle`), e);
                    return;
                }
            }));
        }
        catch (e) {
            console.log(chalk_1.default.bgRedBright(`Something failed during SSL certificate backup`), e);
            return;
        }
    }
    backupCert() {
        return __awaiter(this, void 0, void 0, function* () {
            console.log(chalk_1.default.bgGreenBright(`Backing up SSL certificate from EC2 instance ${this.instanceId}`));
            const domainName = this.options.domainName;
            const certificateSummary = yield acm_utils_1.getCertificate(this.acmClient, domainName);
            let certPem;
            let chainPem;
            let privkeyPem;
            try {
                certPem = fs_1.default.readFileSync(`/etc/letsencrypt/live/${domainName}/cert.pem`, {
                    encoding: 'utf8'
                });
            }
            catch (e) {
                console.log(chalk_1.default.bgRedBright(`Failed to read contents of cert.pem`), e);
                return;
            }
            try {
                chainPem = fs_1.default.readFileSync(`/etc/letsencrypt/live/${domainName}/chain.pem`, {
                    encoding: 'utf8'
                });
            }
            catch (e) {
                console.log(chalk_1.default.bgRedBright(`Failed to read contents of chain.pem`), e);
                return;
            }
            try {
                privkeyPem = fs_1.default.readFileSync(`/etc/letsencrypt/live/${domainName}/privkey.pem`, {
                    encoding: 'utf8'
                });
            }
            catch (e) {
                console.log(chalk_1.default.bgRedBright(`Failed to read contents of privkey.pem`), e);
                return;
            }
            try {
                const result = yield this.acmClient
                    .importCertificate(Object.assign({ Certificate: Buffer.from(certPem), PrivateKey: Buffer.from(privkeyPem), CertificateChain: Buffer.from(chainPem) }, (typeof certificateSummary !== 'undefined' && {
                    CertificateArn: certificateSummary.CertificateArn
                })))
                    .promise();
                console.log(chalk_1.default.greenBright(`Successfully  ${typeof certificateSummary !== 'undefined'
                    ? 'update'
                    : 'import'} certificate to ACM`), result);
            }
            catch (e) {
                console.log(chalk_1.default.bgRedBright(`Failed to ${typeof certificateSummary !== 'undefined'
                    ? 'update'
                    : 'import'} certificate into ACM`), e);
                return;
            }
        });
    }
}
exports.BackupSslCert = BackupSslCert;
//# sourceMappingURL=backup-ssl-cert.js.map