#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const package_json_1 = require("../package.json");
const backup_ssl_cert_1 = require("./backup-ssl-cert");
const openvpn_unattended_install_1 = require("./openvpn-unattended-install");
const pihole_unattended_install_js_1 = require("./pihole-unattended-install.js");
const program = new commander_1.Command();
program.name(package_json_1.name).version(package_json_1.version);
program
    .command(`setup-openvpn`)
    .description('Sets up SSL for OpenVPN Access Server Web UI')
    .option(`-i, --ip [value]`, `The private ip address of the pi hole ec2 instance (for setting up upstream dns)`)
    .option(`-c, --cert-environment [value]`, `Which environment should be used when requesting SSL cert from Lets Encrypt (staging, production)`, 'production')
    .requiredOption(`-h --host-name [value]`, `The FQDN (or private ip, though not recommended) to be used as the host name of the OpenVPN Access Server`)
    .requiredOption(`-d, --domain-name [value]`, `The domain name to use to register the SSL certificate`)
    .requiredOption(`-e, --email [value]`, `The email to use to register the SSL certificate`)
    .requiredOption(`-r --region [value]`, `The AWS region to use when using the SDK to communicate with AWS`)
    .requiredOption(`-u, --user-name [value]`, `The username of the client user`)
    .requiredOption(`-p, --user-password [value]`, `The password of the client user (special characters need to be escaped before they are passed here)`)
    .action((...args) => {
    new openvpn_unattended_install_1.SetupOpenVpn(args[0]);
});
program
    .command(`setup-pihole`)
    .description(`Sets up unbound as a recursive DNS provider and sets up unbound to use it`)
    .requiredOption(`-r --region [value]`, `The AWS region to use when using the SDK to communicate with AWS`)
    .requiredOption(`-p, --password [value]`, `The password to login to the web interface (special characters need to be escaped before they are passed here)`)
    .action((...args) => {
    new pihole_unattended_install_js_1.SetupPiHole(args[0]);
});
program
    .command(`backup-ssl-cert`)
    .description(`Takes a backup of the SSL certificate generated by a Lets Encrypt installation installed in an EC2 instance running Amazon Linux 2 image`)
    .requiredOption(`-d, --domain-name [value]`, `The domain name to use to register the SSL certificate`)
    .requiredOption(`-r --region [value]`, `The AWS region to use when using the SDK to communicate with AWS`)
    .requiredOption(`-a --auto-scaling-group-name [value]`, `The name of the auto scaling group where lifecycle operations are being triggered`)
    .requiredOption(`-l --lifecycle-hook-name [value]`, `The lifecycle hook name`)
    .requiredOption(`-t --lifecycle-action-token [value]`, `The lifecycle token (needed for completing the hook)`)
    .action((...args) => {
    new backup_ssl_cert_1.BackupSslCert(args[0]);
});
program.parse(process.argv);
//# sourceMappingURL=index.js.map